@@ -31,8 +31,10 @@ describe 'sahara' do
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_user').with_value('sahara') }
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_tenant_name').with_value('services') }
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_password').with_value('secrete').with_secret(true) }
-      it { is_expected.to contain_sahara_config('keystone_authtoken/memcached_servers').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_sahara_config('DEFAULT/plugins').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with passing params' do
@@ -45,7 +47,6 @@ describe 'sahara' do
         :admin_user            => 'sahara-user',
         :admin_tenant_name     => 'sahara-tenant',
         :admin_password        => 'new_password',
-        :memcached_servers     => '1.1.1.1:11211',
         :plugins               => ['plugin1', 'plugin2'],
       }
       end
@@ -58,7 +59,6 @@ describe 'sahara' do
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_user').with_value('sahara-user') }
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_tenant_name').with_value('sahara-tenant') }
       it { is_expected.to contain_sahara_config('keystone_authtoken/admin_password').with_value('new_password').with_secret(true) }
-      it { is_expected.to contain_sahara_config('keystone_authtoken/memcached_servers').with_value('1.1.1.1:11211') }
       it { is_expected.to contain_sahara_config('DEFAULT/plugins').with_value('plugin1,plugin2') }
     end
 
@@ -79,18 +79,21 @@ describe 'sahara' do
          it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>') }
          it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>') }
          it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>') }
-         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_ensure('absent') }
+         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
       end
 
       context 'when passing params' do
         before do
           params.merge!({
-            :rabbit_password     => 'pass',
-            :rabbit_userid       => 'guest2',
-            :rabbit_host         => 'localhost2',
-            :rabbit_port         => '5673',
-            :rabbit_ha_queues    => 'true',
-            :amqp_durable_queues => 'true',
+            :rabbit_password         => 'pass',
+            :rabbit_userid           => 'guest2',
+            :rabbit_host             => 'localhost2',
+            :rabbit_port             => '5673',
+            :rabbit_ha_queues        => 'true',
+            :amqp_durable_queues     => 'true',
+            :kombu_reconnect_delay   => '1.0',
+            :kombu_compression       => 'gzip',
+            :kombu_failover_strategy => 'round-robin',
           })
         end
 
@@ -100,14 +103,17 @@ describe 'sahara' do
         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_port').with_value('5673') }
         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('true') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_ensure('absent') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('1.0') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_compression').with_value('gzip') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/kombu_failover_strategy').with_value('round-robin') }
       end
 
       context 'with rabbit ssl cert parameters' do
         before do
           params.merge!({
             :rabbit_password    => 'pass',
-            :rabbit_use_ssl     => 'true',
+            :rabbit_use_ssl     => true,
             :kombu_ssl_ca_certs => '/etc/ca.cert',
             :kombu_ssl_certfile => '/etc/certfile',
             :kombu_ssl_keyfile  => '/etc/key',
@@ -152,7 +158,7 @@ describe 'sahara' do
         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_host').with_value('localhost2') }
         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_port').with_value('5673') }
         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
-        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_ensure('absent') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('<SERVICE DEFAULT>') }
       end
 
       context 'when passing params for multiple rabbit hosts' do
@@ -167,8 +173,8 @@ describe 'sahara' do
         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_userid').with_value('guest3') }
         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_hosts').with_value('nonlocalhost3:5673,nonlocalhost4:5673') }
         it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('true') }
-        it { is_expected.to_not contain_sahara_config('oslo_messaging_rabbit/rabbit_port') }
-        it { is_expected.to_not contain_sahara_config('oslo_messaging_rabbit/rabbit_host') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>') }
       end
     end
 
@@ -203,6 +209,55 @@ describe 'sahara' do
         it { is_expected.to contain_sahara_config('DEFAULT/rpc_cast_timeout').with_value('30') }
       end
     end
+
+    context 'with amqp rpc' do
+      before do
+        params.merge!({ :rpc_backend => 'amqp' })
+      end
+
+      context 'with default parameters' do
+        it { is_expected.to contain_sahara_config('DEFAULT/rpc_backend').with_value('amqp') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/container_name').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/idle_timeout').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/trace').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/ssl_ca_file').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/ssl_cert_file').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/ssl_key_file').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/ssl_key_password').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/allow_insecure_clients').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/sasl_mechanisms').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/sasl_config_dir').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/sasl_config_name').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/username').with_value('<SERVICE DEFAULT>') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/password').with_value('<SERVICE DEFAULT>') }
+      end
+
+      context 'when pass parameters' do
+        before do
+          params.merge!({
+            :amqp_idle_timeout  => '60',
+            :amqp_trace         => true,
+            :amqp_ssl_ca_file   => '/etc/ca.cert',
+            :amqp_ssl_cert_file => '/etc/certfile',
+            :amqp_ssl_key_file  => '/etc/key',
+            :amqp_username      => 'amqp_user',
+            :amqp_password      => 'password',
+          })
+        end
+
+        it { is_expected.to contain_sahara_config('DEFAULT/rpc_backend').with_value('amqp') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/idle_timeout').with_value('60') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/trace').with_value('true') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/ssl_ca_file').with_value('/etc/ca.cert') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/ssl_cert_file').with_value('/etc/certfile') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/ssl_key_file').with_value('/etc/key') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/username').with_value('amqp_user') }
+        it { is_expected.to contain_sahara_config('oslo_messaging_amqp/password').with_value('password') }
+      end
+    end
   end
 
   shared_examples_for 'sahara ssl' do
@@ -215,7 +270,7 @@ describe 'sahara' do
     context 'with ssl' do
       let :params do
       {
-        :use_ssl   => 'true',
+        :use_ssl   => true,
         :ca_file   => '/tmp/ca_file',
         :cert_file => '/tmp/cert_file',
         :key_file  => '/tmp/key_file',
@@ -226,20 +281,10 @@ describe 'sahara' do
       it { is_expected.to contain_sahara_config('ssl/key_file').with_value('/tmp/key_file') }
     end
 
-    context 'with ssl but without ca_file' do
-      let :params do
-      {
-        :use_ssl   => 'true',
-      }
-      end
-      it_raises 'a Puppet::Error', /The ca_file parameter is required when use_ssl is set to true/
-    end
-
     context 'with ssl but without cert_file' do
       let :params do
       {
-        :use_ssl   => 'true',
-        :ca_file   => '/tmp/ca_file',
+        :use_ssl   => true,
       }
       end
       it_raises 'a Puppet::Error', /The cert_file parameter is required when use_ssl is set to true/
@@ -248,8 +293,7 @@ describe 'sahara' do
     context 'with ssl but without key_file' do
       let :params do
       {
-        :use_ssl   => 'true',
-        :ca_file   => '/tmp/ca_file',
+        :use_ssl   => true,
         :cert_file => '/tmp/cert_file',
       }
       end
